summaryrefslogtreecommitdiff
path: root/src/gui
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2010-02-09 13:21:05 +0100
committerSebastien Helleu <flashcode@flashtux.org>2010-02-09 13:21:05 +0100
commitdaee18621e752a1047337acbfd56e3d40d12976f (patch)
tree0479920b78ed61e3d92f28426847c22f89603747 /src/gui
parent71d77a58903bc39341e8ecdda16f8a607355d6f1 (diff)
downloadweechat-daee18621e752a1047337acbfd56e3d40d12976f.zip
Rename command /silence to /mute
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/gui-chat.c12
-rw-r--r--src/gui/gui-chat.h12
2 files changed, 12 insertions, 12 deletions
diff --git a/src/gui/gui-chat.h b/src/gui/gui-chat.h
index 460b8eb6f..0cc3caaa9 100644
--- a/src/gui/gui-chat.h
+++ b/src/gui/gui-chat.h
@@ -42,18 +42,18 @@ enum t_gui_chat_prefix
GUI_CHAT_NUM_PREFIXES,
};
-enum t_gui_chat_silent
+enum t_gui_chat_mute
{
- GUI_CHAT_SILENT_DISABLED = 0,
- GUI_CHAT_SILENT_BUFFER,
- GUI_CHAT_SILENT_ALL_BUFFERS,
+ GUI_CHAT_MUTE_DISABLED = 0,
+ GUI_CHAT_MUTE_BUFFER,
+ GUI_CHAT_MUTE_ALL_BUFFERS,
};
extern char *gui_chat_prefix[GUI_CHAT_NUM_PREFIXES];
extern char gui_chat_prefix_empty[];
extern int gui_chat_time_length;
-extern int gui_chat_silent;
-extern struct t_gui_buffer *gui_chat_silent_buffer;
+extern int gui_chat_mute;
+extern struct t_gui_buffer *gui_chat_mute_buffer;
/* chat functions */
diff --git a/src/gui/gui-chat.c b/src/gui/gui-chat.c
index 061654a54..8bafd0458 100644
--- a/src/gui/gui-chat.c
+++ b/src/gui/gui-chat.c
@@ -50,8 +50,8 @@ char *gui_chat_buffer = NULL; /* buffer for printf */
char *gui_chat_prefix[GUI_CHAT_NUM_PREFIXES]; /* prefixes */
char gui_chat_prefix_empty[] = ""; /* empty prefix */
int gui_chat_time_length = 0; /* length of time for each line (in chars) */
-int gui_chat_silent = GUI_CHAT_SILENT_DISABLED; /* silence mode */
-struct t_gui_buffer *gui_chat_silent_buffer = NULL; /* buffer for silence */
+int gui_chat_mute = GUI_CHAT_MUTE_DISABLED; /* mute mode */
+struct t_gui_buffer *gui_chat_mute_buffer = NULL; /* mute buffer */
/*
@@ -455,10 +455,10 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
return;
}
- /* if silent is enabled for buffer (or all buffers), then just return */
- if ((gui_chat_silent == GUI_CHAT_SILENT_ALL_BUFFERS)
- || ((gui_chat_silent == GUI_CHAT_SILENT_BUFFER)
- && (gui_chat_silent_buffer == buffer)))
+ /* if mute is enabled for buffer (or all buffers), then just return */
+ if ((gui_chat_mute == GUI_CHAT_MUTE_ALL_BUFFERS)
+ || ((gui_chat_mute == GUI_CHAT_MUTE_BUFFER)
+ && (gui_chat_mute_buffer == buffer)))
return;
if (!gui_chat_buffer)